Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(101)

Unified Diff: Source/WebCore/platform/graphics/chromium/Canvas2DLayerChromium.cpp

Issue 7631029: Merge 91736 - Source/WebCore: Removed support for the GL_latch_CHROMIUM extension which Chromium ... (Closed) Base URL: http://svn.webkit.org/repository/webkit/branches/chromium/835/
Patch Set: Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/WebCore/ChangeLog ('k') | Source/WebCore/platform/graphics/chromium/DrawingBufferChromium.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/WebCore/platform/graphics/chromium/Canvas2DLayerChromium.cpp
===================================================================
--- Source/WebCore/platform/graphics/chromium/Canvas2DLayerChromium.cpp (revision 93242)
+++ Source/WebCore/platform/graphics/chromium/Canvas2DLayerChromium.cpp (working copy)
@@ -88,12 +88,10 @@
context->texParameteri(GraphicsContext3D::TEXTURE_2D, GraphicsContext3D::TEXTURE_WRAP_S, GraphicsContext3D::CLAMP_TO_EDGE);
context->texParameteri(GraphicsContext3D::TEXTURE_2D, GraphicsContext3D::TEXTURE_WRAP_T, GraphicsContext3D::CLAMP_TO_EDGE);
m_textureChanged = false;
// FIXME: The finish() here is required because we have to make sure that the texture created in this
// context (the compositor context) is actually created by the service side before the child context
- // attempts to use it (in publishToPlatformLayer). finish() is currently the only call with strong
- // enough semantics to promise this, but is actually much stronger. Ideally we'd do something like
- // inserting a fence here and waiting for it before trying to publish.
- context->finish();
+ // attempts to use it (in publishToPlatformLayer).
+ context->flush();
}
// Update the contents of the texture used by the compositor.
if (m_contentsDirty) {
@@ -88,12 +88,10 @@
context->texParameteri(GraphicsContext3D::TEXTURE_2D, GraphicsContext3D::TEXTURE_WRAP_T, GraphicsContext3D::CLAMP_TO_EDGE);
m_textureChanged = false;
- // FIXME: The finish() here is required because we have to make sure that the texture created in this
+ // The flush() here is required because we have to make sure that the texture created in this
// context (the compositor context) is actually created by the service side before the child context
« no previous file with comments | « Source/WebCore/ChangeLog ('k') | Source/WebCore/platform/graphics/chromium/DrawingBufferChromium.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698